@@ -2,7 +2,7 @@
 /*! @file apolloron.h
     @brief Header file of libapolloron.
     @author Tachibanamasashi, Apolloron Project.
-    @date 2009-07-18
+    @date 2009-09-21
  ******************************************************************************/
 
 #ifndef _APOLLORON_H_
@@ -16,7 +16,7 @@ class Keys;
 
 /*! @brief Version of libapolloron.
  */
-#define LIBAPOLLORON_VERSION "0.43.7"
+#define LIBAPOLLORON_VERSION "0.43.9"
 
 
 /*----------------------------------------------------------------------------*/
@@ -397,7 +397,9 @@ public:
   virtual bool delKey(const char *key);
 
   // Files
+  virtual bool loadFile(const String &filename);
   virtual bool loadFile(const char *filename);
+  virtual bool saveFile(const String &filename) const;
   virtual bool saveFile(const char *filename) const;
 };
 
@@ -545,6 +547,7 @@ class CGI {
 protected:
   Keys requestData; // CGI request values
   Keys requestFileName; // CGI request file names
+  Keys cookie; // CGI request file names
 public:
   CGI(int argc, const char *argv[]);
   virtual ~CGI();
@@ -552,10 +555,11 @@ public:
   // Deletion of object instance
   virtual bool clear();
 
-  virtual String& getValue(const String &key, const char * src_charset = "UTF-8", const char * dest_charset = "UTF-8");
-  virtual String& getValue(const char *key, const char * src_charset = "UTF-8", const char * dest_charset = "UTF-8");
+  virtual String& getValue(const String &key);
+  virtual String& getValue(const char *key);
   virtual String& getFileName(const String &key, const char * src_charset = "UTF-8", const char * dest_charset = "UTF-8");
   virtual String& getFileName(const char *key, const char * src_charset = "UTF-8", const char * dest_charset = "UTF-8");
+  virtual String& getCookie(const char *key, const char * src_charset = "UTF-8", const char * dest_charset = "UTF-8");
 };
 
 
