@@ -706,6 +706,16 @@ bool Keys::delKey(const char *key) {
 }
 
 
+/*! Read structured text file into a Keys.
+    @param filename  File name to read.
+    @retval true  success
+    @retval false failure
+ */
+bool Keys::loadFile(const String &filename) {
+  return (*this).loadFile((const char *)(filename.c_str()));
+}
+
+
 /*! Read structured text file into a Keys.
     @param filename  File name to read.
     @retval true  success
@@ -754,6 +764,16 @@ bool Keys::loadFile(const char *filename) {
   return true;
 }
 
+/*! Write structured text file of serialized Keys.
+    @param filename  File name to wtite.
+    @retval true  success
+    @retval false failure
+ */
+bool Keys::saveFile(const String &filename) const {
+  return (*this).saveFile((const char *)(filename.c_str()));
+}
+
+
 /*! Write structured text file of serialized Keys.
     @param filename  File name to wtite.
     @retval true  success
